@@ -1,18 +1,18 @@
+import itertools
+import logging
+import os
+import re
+from pathlib import Path
+from typing import Mapping
+
 import numpy as np
 import pandas as pd
-import re
-import os
 import yaml
-import itertools
-from typing import Mapping
-from larch import P, X, DataFrames, Model
+from larch import DataFrames, Model, P, X
+from larch.log import logger_name
 from larch.model.abstract_model import AbstractChoiceModel
 from larch.model.tree import NestingTree
 from larch.util import Dict
-from pathlib import Path
-
-import logging
-from larch.log import logger_name
 
 _logger = logging.getLogger(logger_name)
 
@@ -143,7 +143,10 @@ def linear_utility_from_spec(spec, x_col, p_col, ignore_x=(), segment_id=None):
         partial_utility = {}
         for seg_p_col, segval in p_col.items():
             partial_utility[seg_p_col] = linear_utility_from_spec(
-                spec, x_col, seg_p_col, ignore_x,
+                spec,
+                x_col,
+                seg_p_col,
+                ignore_x,
             ) * X(f"{segment_id}=={str_repr(segval)}")
         return sum(partial_utility.values())
     parts = []
@@ -263,7 +266,9 @@ def explicit_value_parameters_from_spec(spec, p_col, model):
                 pass
             else:
                 model.set_value(
-                    getattr(i, p_col), value=j, holdfast=True,
+                    getattr(i, p_col),
+                    value=j,
+                    holdfast=True,
                 )
 
 
@@ -318,14 +323,17 @@ def apply_coefficients(coefficients, model, minimum=None, maximum=None):
         assert "value" in coefficients.columns
         if "constrain" not in coefficients.columns:
             import warnings
-            warnings.warn("coefficient dataframe missing 'constrain' column, setting all to 'F'")
+
+            warnings.warn(
+                "coefficient dataframe missing 'constrain' column, setting all to 'F'"
+            )
             coefficients["constrain"] = "F"
         assert coefficients.index.name == "coefficient_name"
         assert isinstance(model, AbstractChoiceModel)
         explicit_value_parameters(model)
         for i in coefficients.itertuples():
             if i.Index in model:
-                holdfast = (i.constrain == "T")
+                holdfast = i.constrain == "T"
                 if holdfast:
                     minimum_ = i.value
                     maximum_ = i.value
@@ -482,7 +490,7 @@ def clean_values(
     return values
 
 
-def update_coefficients(model, data, result_dir=Path('.'), output_file=None):
+def update_coefficients(model, data, result_dir=Path("."), output_file=None):
     if isinstance(data, pd.DataFrame):
         coefficients = data.copy()
     else:
@@ -492,7 +500,7 @@ def update_coefficients(model, data, result_dir=Path('.'), output_file=None):
     if output_file is not None:
         os.makedirs(result_dir, exist_ok=True)
         coefficients.reset_index().to_csv(
-            result_dir/output_file,
+            result_dir / output_file,
             index=False,
         )
     return coefficients
